==> musicman-0.8.6.tar.gz: musicman/musicman/musicindexgenerator.h <==
/***************************************************************************
                          musicindexgenerator.h  -  description
                             -------------------
    begin                : Sun Jun 1 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MUSICINDEXGENERATOR_H
#define MUSICINDEXGENERATOR_H

#include <qstring.h>
#include <kurl.h>
#include <kio/jobclasses.h>
#include <qdict.h>
#include <kfileitem.h>
#include "musicfolderinfo.h"

typedef QMap<QString,KFileItemList> MusicList;
typedef QMap<QString,MusicFolderInfo> FoldersInfo;
class DialogIndexerInfo;

/**Many algorithms for HTML, XML, KWord, Text format MP3 CD index creation
  *@author Avi Alkalay
  */

class MusicIndexGenerator : public QObject {
	Q_OBJECT
public: 
	MusicIndexGenerator(const KURL &_base, QWidget *_parent, QString &_htmlTemplate, QString &_coverTemplate);
	MusicIndexGenerator(const KURL &_base, QWidget *_parent);
	virtual ~MusicIndexGenerator();
	/** Create the nice HTML index */
	void createHTML();
	/** Create the KWord document with full music files listing to be printed and used as CD cover. Additionally, runs KWord to let the user make final adjustements and generate PDF. */
	void createCover();
	/** Write property of QString CDName. */
	void setCDName( const QString& _newVal);
	/** Read property of QString CDName. */
	const QString& getCDName();
	/** Write property of KURL base. */
	void setbase( const KURL& _newVal);
	/** Read property of KURL base. */
	const KURL& getbase();
	/** Returns the basename of a full path, similar to the basename(1) unix command.

	baseName("/dir1/dir2/file.txt") == "file.txt" */
	static QString baseName(const QString &path);

	/** Returns the dirname of a full path, similar to the dirname(1) unix command.

   dirName("/dir1/dir2/file.txt") == "/dir1/dir2" */
	QString dirName(const QString &path);
	QString dirName(const KIO::UDSEntry &path);

	bool isMusic(const QString &path);
	bool isMusic(const KIO::UDSEntry &path);


  /** Create the text indexes in info/ folder

     collections.txt: Only the folder names
     musicdb.txt: Full music files listing with file size, duration and quality
     music.txt: Almost human readable listing of files per folder
  */
	void createText();
  /** Create the M3U file in each folder, if solicited by user. */
  void createM3U();
  
private:
	/** The real constructor. All other constructors actually call this method */
	void subConstructor(const KURL &_base, QString &_htmlTemplate, QString &_coverTemplate);
	/** Cleans a raw filename to a nicer representations, substituting _s to spaces, "/" to " :: ", removing file extensions, etc */
	QString clean(QString s);
	/** Returns the string for the playing time represented as hh:mm:ss */
	QString nicePlayingTime(unsigned long secs);
	/** Details of creating the user supplied info dialog. */
	void userDialog();
	/** Return the list of all resources inside the rel directories. Same functionality as KStandardDirs::findAllResources, but didn't worked for a konqueror plugin. */
	QStringList getSubItems(const QString &rel);

	/** Called when all files info was retrieved, and now we are ready to generate indexes. */
	void infoBuilderFinished();

	/** The CD title, to be used in cover, HTML, etc */
	QString CDName;

	/** The base folder we'll index */
	KURL base;

	/** Holds a list of all music files in a subdirectory. It maps a folder name (QString) to the list of its files (KFileItemList). */
	MusicList musicList;

	/** Holds the folders statistical info */
	FoldersInfo foldersInfo;
  
	/** An internal filenames list, used in the process of creating the complex structure for the indexes. */
	QStringList fileNames;

	/** Name of the template to use for the HTML index */
	QString htmlTemplate;

	/** Name of the template to use for the CD cover */
	QString coverTemplate;

	/** Filename of the playlist in each folder */
	QString m3uFilename;

	/** A string representation of the CD root directory. */
	QString root;

	/** The list of template files that instegrates the KWord file for the cover. */
	QStringList coverFiles;

	/** Point the the template dir we'll use for the cover */
	QString coverTemplateDir;

	/** The cover filename extension.
	Since KOffice and OpenOffice docs are all zip files, the template-based
	cover-generation engine is the same, so we need the filename extension
	to generate a correct filename, based on the template. */
	QString coverFilenameExtension;

	/** A KWord template for a table of contents entry */
	QString coverFolderTemplate;

	/** A KWord template for a folder entry in the long song list */
	QString coverListFolderTemplate;

	/** A KWord template for a song entry in the long song list */
	QString coverListSongTemplate;

	/** The dialog to ask user some questions regarding how to build the indexes. */
	DialogIndexerInfo * dialogIndexerInfo;

	QWidget * parent;

private slots: // Private slots
	/** Called after each sub-folder list job finishes. It will build the musicList and folderList vars. */
	void buildMusicListFase1(KIO::Job *job,const KIO::UDSEntryList &list);
	void buildMusicListFase2(KIO::Job *job);

	/** Given a folder, will create all necessary static files for a nice CD. Like images, the basic diretories resource and info, CD icon, Windows autorun.inf, etc */
	void prepareCDLayout();

	/** Second stage of the cover creation. Will be called after the template copy job finishes. */
	void createCoverStage2(KIO::Job *);

	void collectCoverFiles(KIO::Job *job,const KIO::UDSEntryList &list);
	/** Called when the user accepts the DialogIndexerInfo. Will update some internal vars to correctly generate the indexes. */
	void updateFromDialog();
	/** Called when the user finished interacting the the dialog. */
	void setDialogFinished();
	/** The starting point to create all music indexes, prepare CD layout, and destructors. */
	void createAll();

signals: // Signals

public slots: // Public slots
	/** Encapsulates all index files creation methods */
	void createIndexes();

public: // Public attributes
	/** True if the user clicked OK in the dialog. */
	bool userAccepted;

	/** True if user finished to interact with the dialog. */
	bool dialogFinished;

	/** True if all music files info-gathering engines are over. */
	bool haveAllFilesInfo;
};

#endif

==> musicman-0.11.tar.gz: musicman/musicman/musicindexgenerator.h <==
/***************************************************************************
                          musicindexgenerator.h  -  description
                             -------------------
    begin                : Sun Jun 1 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MUSICINDEXGENERATOR_H
#define MUSICINDEXGENERATOR_H

#include <qstring.h>
#include <kurl.h>
#include <kio/jobclasses.h>
#include <qdict.h>
#include <kfileitem.h>
#include <qvaluelist.h>
#include <kdesktopfile.h>
#include <kcombobox.h>

#include "musicfolderinfo.h"

typedef QMap<QString,KFileItemList> MusicList;
typedef QMap<QString,MusicFolderInfo> FoldersInfo;
typedef QPtrList<KDesktopFile> TemplateList;
class DialogIndexerInfo;

/**Many algorithms for HTML, XML, KWord, Text format MP3 CD index creation
  *@author Avi Alkalay
  */

class MusicIndexGenerator : public QObject {
	Q_OBJECT
public: 
	MusicIndexGenerator(const KURL &_base, QWidget *_parent, QString &_htmlTemplate, QString &_coverTemplate);
	MusicIndexGenerator(const KURL &_base, QWidget *_parent);
	virtual ~MusicIndexGenerator();
	/** Create the nice HTML index */
	void createHTML();
	/** Create the KWord document with full music files listing to be printed and used as CD cover. Additionally, runs KWord to let the user make final adjustements and generate PDF. */
	void createCover();
	/** Write property of QString CDName. */
	void setCDName( const QString& _newVal);
	/** Read property of QString CDName. */
	const QString& getCDName();
	/** Write property of KURL base. */
	void setbase( const KURL& _newVal);
	/** Read property of KURL base. */
	const KURL& getbase();
	/** Returns the basename of a full path, similar to the basename(1) unix command.

	baseName("/dir1/dir2/file.txt") == "file.txt" */
	static QString baseName(const QString &path);

	/** Returns the dirname of a full path, similar to the dirname(1) unix command.

   dirName("/dir1/dir2/file.txt") == "/dir1/dir2" */
	QString dirName(const QString &path);
	QString dirName(const KIO::UDSEntry &path);

	bool isMusic(const QString &path);
	bool isMusic(const KIO::UDSEntry &path);


  /** Create the text indexes in info/ folder

     collections.txt: Only the folder names
     musicdb.txt: Full music files listing with file size, duration and quality
     music.txt: Almost human readable listing of files per folder
  */
	void createText();
  /** Create the M3U file in each folder, if solicited by user. */
  void createM3U();
  
private:
	/** The real constructor. All other constructors actually call this method */
	void subConstructor(const KURL &_base, QString &_htmlTemplate, QString &_coverTemplate);
        /** converts the single quotes to two singel quotes for sql export */
        QString convertSQLString(QString s);
        /** returns "NULL" (an empty DB field), if string is null */
        QString sqlCheckNULL(QString s);
	/** Cleans a raw filename to a nicer representations, substituting _s to spaces, "/" to " :: ", removing file extensions, etc */
	QString clean(QString s);
/** Makes a text XML (HTML) user friendly. Used in OpenOffice (XML) cover creation. */
	QString xmlize(QString s);
	/** Returns the string for the playing time represented as hh:mm:ss */
	QString nicePlayingTime(unsigned long secs);
	/** Details of creating the user supplied info dialog. */
	void userDialog();
	/** Return the list of all resources inside the rel directories. Same functionality as KStandardDirs::findAllResources, but didn't worked for a konqueror plugin. */
	QStringList getSubItems(const QString &rel);

	/** Called when all files info was retrieved, and now we are ready to generate indexes. */
	void infoBuilderFinished();
	
  /** Look inside the passed base directory for .desktop files defining HTML or cover templates. Then feeds the passed 'show' combobox with discovered cover icons and descriptions. */
  void fetchTemplates(QString base,TemplateList &htmlOrCover,KComboBox *show);

	/** The CD title, to be used in cover, HTML, etc */
	QString CDName;

	/** The base folder we'll index */
	KURL base;

	/** Holds a list of all music files in a subdirectory. It maps a folder name (QString) to the list of its files (KFileItemList). */
	MusicList musicList;

	/** The list of .desktop files defining HTML and cover templates */
	TemplateList coverTemplates,htmlTemplates;

	/** Holds the folders statistical info */
	FoldersInfo foldersInfo;
  
	/** An internal filenames list, used in the process of creating the complex structure for the indexes. */
	QStringList fileNames;

	/** Points to the selected HTML template .desktop file which compiles all info needed for an index */
	KDesktopFile *htmlTemplate;
	/** Name of the template to use for the HTML index */
	//QString htmlTemplate;

	/** Points to the selected cover template .desktop file which compiles all info needed for a cover */
	KDesktopFile *coverTemplate;
	/** Name of the template to use for the CD cover */
	//QString coverTemplate;

	/** Filename of the playlist in each folder */
	QString m3uFilename;

	/** A string representation of the CD root directory. */
	QString root;

	/** The list of template files that integrates the KWord file for the cover. */
	QStringList coverFiles;

	/** Points to the template dir we'll use for the cover */
	QString coverTemplateDir;

	/** A KWord template for a table of contents entry */
	QString coverFolderTemplate;

	/** A KWord template for a folder entry in the long song list */
	QString coverListFolderTemplate;

	/** A KWord template for a song entry in the long song list */
	QString coverListSongTemplate;

	/** A template to be used before a list of song entries in the long song list */
	QString coverPreListSongTemplate;

	/** A template to be used after a list of song entries in the long song list */
	QString coverPostListSongTemplate;

	/** The dialog to ask user some questions regarding how to build the indexes. */
	DialogIndexerInfo * dialogIndexerInfo;

	QWidget * parent;

private slots: // Private slots
	/** Called after each sub-folder list job finishes. It will build the musicList and folderList vars. */
	void buildMusicListFase1(KIO::Job *job,const KIO::UDSEntryList &list);
	void buildMusicListFase2(KIO::Job *job);

	/** Given a folder, will create all necessary static files for a nice CD. Like images, the basic diretories resource and info, CD icon, Windows autorun.inf, etc */
	void prepareCDLayout();

	/** Second stage of the cover creation. Will be called after the template copy job finishes. */
	void createCoverStage2(KIO::Job *);

	void collectCoverFiles(KIO::Job *job,const KIO::UDSEntryList &list);
	/** Called when the user accepts the DialogIndexerInfo. Will update some internal vars to correctly generate the indexes. */
	void updateFromDialog();
	/** Called when the user finished interacting the the dialog. */
	void setDialogFinished();
	/** The starting point to create all music indexes, prepare CD layout, and destructors. */
	void createAll();

signals: // Signals

public slots: // Public slots
	/** Encapsulates all index files creation methods */
	void createIndexes();

public: // Public attributes
	/** True if the user clicked OK in the dialog. */
	bool userAccepted;

	/** True if user finished to interact with the dialog. */
	bool dialogFinished;

	/** True if all music files info-gathering engines are over. */
	bool haveAllFilesInfo;
};

#endif
